# UP-NLP

The Université Paris NLP package (upnlp) is meant to provide support for teaching Natural Language Processing
(NLP) at graduate level. It targets computational linguists, cognitive scientists
and computer scientists.  It aims to help students to get a smooth introduction to modern 
libraries and tools used nowadays in NLP without getting lost into the gory details
and without requiring insanely heavy computational resources.

Thus the library provides:

* Convenient access to small scale data sets relevant for in-class exercises
* Convenient access to small scale language models relevant for in-class exercises.
* A programming interface designed to be easily comparable to real-world full-scale libraries like Huggingface or OpenAI:
  key notions learned with the interface are easy to transfer to real world use cases.


The best way to discover the library is through its documentation.
